==> sisu_0.42.3.orig.tar.gz: sisu-0.42.3.orig/lib/sisu/0.42/dbi.rb <==
=begin
 * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
 * Author: Ralph Amissah
   * http://www.jus.uio.no/sisu
   * http://www.jus.uio.no/sisu/SiSU/download

 * Description: postgresql module, dbi import frame

 * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Ralph Amissah

 * License: GPL 2 or later

  Summary of GPL 2

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the Free
  Software Foundation; either version 2 of the License, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA

  If you have Internet connection, the latest version of the GPL should be
  available at these locations:
    http://www.fsf.org/licenses/gpl.html
    http://www.gnu.org/copyleft/gpl.html
    http://www.jus.uio.no/sisu/gpl2.fsf

  SiSU was first released to the public on January 4th 2005

  SiSU uses:
  
  *  Standard SiSU markup syntax,
  *  Standard SiSU meta-markup syntax, and the
  *  Standard SiSU object citation numbering and system
  
  © Ralph Amissah 1997, current 2006.
  All Rights Reserved.

 * Ralph Amissah: ralph@amissah.com
                  ralph.amissah@gmail.com
=end
module  SiSU_DBI                                                                 #% database building
  require SiSU_lib + '/help'
  require SiSU_lib + '/sysenv'
  include SiSU_Env
  include SiSU_Screen
  require SiSU_lib + '/param'
  include SiSU_Param
  require SiSU_lib + '/common_db'
  include SiSU_DB
  require SiSU_lib + '/common_db_flatfile'
  include SiSU_Format_Shared
  class SiSU_SQL
    def initialize(opt)
      SiSU_Env::Load.new('dbi',true).prog
      @opt=opt
      @db=SiSU_Env::Info_db.new
      if @opt.cmd=~/D/:     @sql_type='pg'
      elsif @opt.cmd =~/d/: @sql_type='sqlite'
      end
    end
    def read_psql
      begin
        db,user,dbi=@db.db_psql,@db.user,@db.dbi_psql
        @conn=DBI.connect(dbi,user,db) 
      rescue
        SiSU_DB::Case.new(@opt,@conn,@sql_type).cases
        @conn=DBI.connect(dbi,user,db) 
      ensure
      end
    end
    def read_sqlite
      begin
        sql_type='sqlite'
        dbi=@db.dbi_sqlite
        @conn=DBI.connect(dbi) 
      rescue
      ensure
      end
    end
    def connect
      case @sql_type
      when /pg/:     read_psql
      when /sqlite/: read_sqlite
      end
      tell=SiSU_Screen::Ansi.new(@opt.cmd,"DBI (#@sql_type) #{@opt.mod}")
      tell.dbi_title unless @opt.cmd =~/q/
      begin
        SiSU_DB::Case.new(@opt,@conn,@sql_type).cases
      rescue:        SiSU_Errors::Info_error.new($!,$@,@cf,@opt.fns).error
      ensure
      end
      begin
      @conn.disconnect if @sql_type =~/sqlite/
      rescue
        connect
      end
    end
  end
end
__END__

==> sisu_0.48.8.orig.tar.gz: sisu-0.48.8.orig/lib/sisu/0.48/dbi.rb <==
=begin
 * Name: SiSU - Simple information Structuring Universe - Structured information, Serialized Units
 * Author: Ralph Amissah
   * http://www.jus.uio.no/sisu
   * http://www.jus.uio.no/sisu/SiSU/download.html

 * Description: postgresql module, dbi import frame

 * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 Ralph Amissah

 * License: GPL 2 or later

  Summary of GPL 2

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the Free
  Software Foundation; either version 2 of the License, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA

  If you have Internet connection, the latest version of the GPL should be
  available at these locations:
    http://www.fsf.org/licenses/gpl.html
    http://www.gnu.org/copyleft/gpl.html
    http://www.jus.uio.no/sisu/gpl2.fsf

  SiSU was first released to the public on January 4th 2005

  SiSU uses:
  
  *  Standard SiSU markup syntax,
  *  Standard SiSU meta-markup syntax, and the
  *  Standard SiSU object citation numbering and system
  
  © Ralph Amissah 1997, current 2006.
  All Rights Reserved.

 * Ralph Amissah: ralph@amissah.com
                  ralph.amissah@gmail.com
=end
module  SiSU_DBI                                                                 #% database building
  require SiSU_lib + '/help'
  require SiSU_lib + '/sysenv'
  include SiSU_Env
  include SiSU_Screen
  require SiSU_lib + '/param'
  include SiSU_Param
  require SiSU_lib + '/shared_db'
  include SiSU_DB
  require SiSU_lib + '/shared_html_lite'
  include SiSU_Format_Shared
  class SiSU_SQL
    def initialize(opt)
      SiSU_Env::Load.new('dbi',true).prog
      @opt=opt
      @db=SiSU_Env::Info_db.new
      if @opt.cmd =~/d/i or  @opt.mod.inspect =~/--pg(?:sql)?|(?:sq)?lite/
        @sql_type=if @opt.cmd=~/D/ or @opt.mod.inspect =~/--pg(?:sql)?/;         'pg'
        elsif @opt.cmd =~/d/ and @opt.mod.inspect =~/--(?:db[=-])?pg(?:sql)?/;   'pg'
        elsif @opt.mod.inspect =~/--(?:sq)?lite/;                                'sqlite'
        elsif @opt.cmd =~/d/ and @opt.mod.inspect =~/--(?:db[=-])?(?:sq)?lite/;  'sqlite'
        #elsif @opt.cmd =~/d/ and @opt.mod.select =~/--my(?:sql)?/;               'mysql'
        else                                                                     'sqlite'
        end
      end
    end
    def read_psql
      begin
        db,user,dbi=@db.db_psql,@db.user,@db.dbi_psql
        @conn=DBI.connect(dbi,user,db) 
      rescue
        if @opt.mod.inspect=~/--(createall|create)/
          puts %{manually create the database: "#{db}" if it does not yet exist}
          #sudo su -p postgres;  createdb #{db}; #[createuser?]
        end
        SiSU_DB::Case.new(@opt,@conn,@sql_type).cases
        @conn=DBI.connect(dbi,user,db) 
      ensure
      end
    end
    def read_sqlite
      begin
        sql_type='sqlite'
        dbi=@db.dbi_sqlite
        @conn=DBI.connect(dbi) 
      rescue
      ensure
      end
    end
    def connect
      case @sql_type
      when /pg/;     read_psql
      when /sqlite/; read_sqlite
      end
      tell=SiSU_Screen::Ansi.new(@opt.cmd,"DBI (#@sql_type) #{@opt.mod}")
      tell.dbi_title unless @opt.cmd =~/q/
      begin
        SiSU_DB::Case.new(@opt,@conn,@sql_type).cases
      rescue;        SiSU_Errors::Info_error.new($!,$@,@cf,@opt.fns).error
      ensure
      end
      begin
      @conn.disconnect if @sql_type =~/sqlite/
      rescue
        connect
      end
    end
  end
end
__END__
